@@ -12,21 +12,25 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import json
 
 import os
 import prettytable
 
 from surveilclient.openstack.common import importutils
-from oslo.serialization import jsonutils
-
+try:
+    from oslo_serialization import jsonutils
+except ImportError:
+    from oslo.serialization import jsonutils
 
 # Decorator for cli-args
 def arg(*args, **kwargs):
     def _decorator(func):
         # Because of the semantics of decorator composition if we just append
-        #  to the options list positional options will appear to be backwards.
+        # to the options list positional options will appear to be backwards.
         func.__dict__.setdefault('arguments', []).insert(0, (args, kwargs))
         return func
+
     return _decorator
 
 
@@ -66,7 +70,7 @@ def print_item(objs, properties):
 
     """ Override the properties keys pass in parameter """
 
-    len_property_max=0
+    len_property_max = 0
     for property in properties:
         if len(property) > len_property_max:
             len_property_max = len(property)
@@ -77,10 +81,14 @@ def print_item(objs, properties):
 
     for property in properties:
         val_lines = []
-        for i in range(0, len(objs[property].__str__()), len_available):
-            val_lines.append(objs[property].__str__()[i:i+len_available])
+        if type(objs[property]) is list and objs[property]:
+            value = json.dumps(objs[property])
+        else:
+            value = objs[property].__str__()
+        for i in range(0, len(value), len_available):
+            val_lines.append(value[i:i + len_available])
 
-        val_lines ='\n'.join(val_lines)
+        val_lines = '\n'.join(val_lines)
         list.append({'prop': property, 'value': val_lines})
 
     formatters = {
@@ -127,3 +135,41 @@ def get_columns(lines, ordered_columns):
             del columns_dict[col]
 
     return valid_columns + sorted(columns_dict.keys())
+
+
+def create_query(**kwargs):
+
+    query = {}
+    filters = {}
+    paging = {}
+    time = {}
+
+    if kwargs:
+        for arg in kwargs:
+            if arg is 'live_query':
+                query = json.loads(kwargs[arg])
+            elif arg in ['page_size', 'page']:
+                paging[arg] = kwargs[arg]
+            elif arg in ['start_time', 'end_time']:
+                time[arg] = kwargs[arg]
+            else:
+                filters[arg] = [kwargs[arg]]
+
+    if time:
+        query["time_interval"] = time
+
+    if paging:
+        query["paging"] = paging
+
+    if filters:
+        if 'filters' not in query:
+           query["filters"] = {}
+        if 'is' not in query["filters"]:
+           query["filters"]["is"] = filters
+        else:
+           query["filters"]["is"].update(filters)
+
+    if 'filters' in query:
+        query['filters'] = json.dumps(query['filters'])
+
+    return query
